<?php
/**
 * Daisycon settings page form group handler
 *
 * @category  Daisycon
 * @package   Daisycon_Affiliatemarketing
 * @copyright Copyright (c) 2018 Daisycon B.V.
 * @author    Daisycon B.V. <support@daisycon.com>
 */
class Daisycon_Affiliatemarketing_Block_Adminhtml_Config_Form_Group
    extends Mage_Adminhtml_Block_System_Config_Form_Fieldset
{
    /**
     * Get the daisycon affiliatemarketing config
     *
     * @return Daisycon_Affiliatemarketing_Model_Config
     */
    protected function _getConfig()
    {
        return Mage::getSingleton('affiliatemarketing/config');
    }

    /**
     * Returns true for program settings
     *
     * @return bool
     */
    protected function _hasPrograms()
    {
        $config = $this->_getConfig();
        $username = $config->getAccountUsername();
        $programs = $config->getGeneralAdvertiserPrograms();
        return false === empty($username) && false === empty($programs);
    }

    /**
     * Override render method to hide form groups when advertiser program tree is not loaded
     *
     * @param Varien_Data_Form_Element_Abstract $element
     * @return string
     */
    public function render(Varien_Data_Form_Element_Abstract $element)
    {
        if ($element instanceof Varien_Data_Form_Element_Fieldset) {
            if (false === $this->_hasPrograms()) {
                if ('affiliatemarketing_account' !== $element->getId()) {
                    $this->getGroup($element)->frontend_class = 'no-display';
                }
            } else {
                if ('affiliatemarketing_account' === $element->getId()) {
                    $element->setExpanded(null);
                    $extra = Mage::getSingleton('admin/session')->getUser()->getExtra();
                    if (true === isset($extra['configState'][$element->getId()])) {
                        $extra['configState'][$element->getId()] = false;
                        Mage::getSingleton('admin/session')->getUser()->setExtra($extra);
                    }
                }
            }
        }

        return parent::render($element);
    }
}
